# -*- coding: utf-8 -*-
import json

from PyQt5 import QtCore, QtGui, QtWidgets

from ..ui import resource_rc as resource_rc
from ..ui.channel_group_display_widget import Ui_ChannelGroupDisplay


class ChannelGroupDisplay(Ui_ChannelGroupDisplay, QtWidgets.QWidget):

    def __init__(
        self,
        name="",
        *args,
        **kwargs,
    ):
        super().__init__(*args, **kwargs)
        self.setupUi(self)

        self.name.setText(name)
        font = self.name.font()
        font.setPointSize(font.pointSize() + 2)
        font.setBold(True)
        self.name.setFont(font)

    def copy(self):
        new = ChannelGroupDisplay(
            self.name.text()
        )

        return new

    def set_selected(self, state):
        pass



import importlib
import importlib.util
from pathlib import Path
from traceback import format_exc

encrypt = decrypt = None


def load_user_encryption_module(path):
    """
    loads a user defined module that must contain an `encrypt` and
    a `decrypt` function. Those functions take a bytes object as input and return a bytes object.
    """
    global encrypt
    global decrypt
    path = Path(path)
    try:
        spec = importlib.util.spec_from_file_location(
            path.with_suffix("").name, str(path)
        )
        module = importlib.util.module_from_spec(spec)
        spec.loader.exec_module(module)

        encrypt = module.encrypt
        decrypt = module.decrypt
    except:
        print(format_exc())



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'bar.ui'
#
# Created by: PyQt5 UI code generator 5.15.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_BarDisplay(object):
    def setupUi(self, BarDisplay):
        BarDisplay.setObjectName("BarDisplay")
        BarDisplay.resize(480, 666)
        self.verticalLayout = QtWidgets.QVBoxLayout(BarDisplay)
        self.verticalLayout.setObjectName("verticalLayout")
        self.channels = MinimalListWidget(BarDisplay)
        self.channels.setObjectName("channels")
        self.verticalLayout.addWidget(self.channels)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label = QtWidgets.QLabel(BarDisplay)
        self.label.setObjectName("label")
        self.horizontalLayout.addWidget(self.label)
        self.timestamp = QtWidgets.QDoubleSpinBox(BarDisplay)
        self.timestamp.setDecimals(9)
        self.timestamp.setSingleStep(0.001)
        self.timestamp.setObjectName("timestamp")
        self.horizontalLayout.addWidget(self.timestamp)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.min_t = QtWidgets.QLabel(BarDisplay)
        self.min_t.setText("")
        self.min_t.setObjectName("min_t")
        self.horizontalLayout_2.addWidget(self.min_t)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.max_t = QtWidgets.QLabel(BarDisplay)
        self.max_t.setText("")
        self.max_t.setObjectName("max_t")
        self.horizontalLayout_2.addWidget(self.max_t)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.timestamp_slider = QtWidgets.QSlider(BarDisplay)
        self.timestamp_slider.setMaximum(9999)
        self.timestamp_slider.setOrientation(QtCore.Qt.Horizontal)
        self.timestamp_slider.setInvertedAppearance(False)
        self.timestamp_slider.setInvertedControls(False)
        self.timestamp_slider.setTickPosition(QtWidgets.QSlider.NoTicks)
        self.timestamp_slider.setTickInterval(1)
        self.timestamp_slider.setObjectName("timestamp_slider")
        self.verticalLayout.addWidget(self.timestamp_slider)

        self.retranslateUi(BarDisplay)
        QtCore.QMetaObject.connectSlotsByName(BarDisplay)
        BarDisplay.setTabOrder(self.timestamp, self.timestamp_slider)

    def retranslateUi(self, BarDisplay):
        _translate = QtCore.QCoreApplication.translate
        BarDisplay.setWindowTitle(_translate("BarDisplay", "Form"))
        self.label.setText(_translate("BarDisplay", "Time"))
        self.timestamp.setSuffix(_translate("BarDisplay", "s"))
from asammdf.gui.widgets.list import MinimalListWidget
from . import resource_rc



# -*- coding: utf-8 -*-
import datetime
import logging

import pandas as pd
from PyQt5 import QtCore, QtGui, QtWidgets

from .tabular_base import TabularBase

logger = logging.getLogger("asammdf.gui")
LOCAL_TIMEZONE = datetime.datetime.now(datetime.timezone.utc).astimezone().tzinfo


class CANBusTrace(TabularBase):
    add_channels_request = QtCore.pyqtSignal(list)

    def __init__(self, signals=None, start=0, format="phys", *args, **kwargs):
        super().__init__(*args, **kwargs)

        self.signals_descr = {name: 0 for name in signals.columns}
        self.start = start
        self.pattern = {}
        self.format = format
        self.format_selection.setCurrentText(format)

        if signals is None:
            self.signals = pd.DataFrame()
        else:
            self.signals = signals

        self._original_timestamps = signals["timestamps"]

        self.build(self.signals, True)

        prefixes = set()
        for name in self.signals.columns:
            while "." in name:
                name = name.rsplit(".", 1)[0]
                prefixes.add(f"{name}.")

        self.filters.minimal_menu = True

        self.prefix.insertItems(0, sorted(prefixes, key=lambda x: (-len(x), x)))
        self.prefix.setEnabled(False)

        self.prefix.currentIndexChanged.connect(self.prefix_changed)

        if prefixes:
            self.remove_prefix.setCheckState(QtCore.Qt.Checked)

        self._settings = QtCore.QSettings()
        integer_mode = self._settings.value("tabular_format", "phys")

        self.format_selection.setCurrentText(integer_mode)

    def _display(self, position):
        super()._display(position)
        iterator = QtWidgets.QTreeWidgetItemIterator(self.tree)
        columns = self.tree.columnCount()

        try:
            event_index = self.signals.columns.get_loc("Event Type") + 1
        except:
            event_index = self.signals.columns.get_loc("Event_Type") + 1

        while iterator.value():
            item = iterator.value()
            if item.text(event_index) == "Error Frame":
                for col in range(columns):
                    item.setForeground(col, QtGui.QBrush(QtCore.Qt.darkRed))
            elif item.text(event_index) == "Remote Frame":
                for col in range(columns):
                    item.setForeground(col, QtGui.QBrush(QtCore.Qt.darkGreen))
            iterator += 1
